﻿using System;
using System.ComponentModel;
using System.Windows.Forms;
using System.Xml;
using System.Collections.Generic;

/// <summary>
/// Wersja pluginu: 1.2
///
/// Kompilacja
///
///     Nazwa pliku .DLL będzie jednocześnie nazwą głównego menu w EU, dlatego zalecane jest wykorzystanie
///     nazwy swojej firmy + integrowanej aplikacji, aby nie powstał konflikt z pluginami innych firm.
///
///     Z pliku DLL będzie skanowana tylko publiczna klasa "PluginEU", dlatego proszę nie zmieniać
///     jej nazwy. Obsługa dodatków znajduję się nad główną listą aukcji/transakcji pod ikonką
///     "z wtyczką". Funkcje widoczne w module Aukcje muszą zaczynać się od prefiksu "A_", natomiast
///     w module Transakcje od "T_". Pozostała część nazwy może być dowolna.
///
/// Instalacja
///
///     Wymagana wersja EU: 3.44.0 lub nowsza
///
///     Plik .DLL, należy umieścić w katalogu "plugins", gdzie są przechowywane dane użytkownika:
///     https://www.easyuploader.pl/forum/viewtopic.php?t=7886
///
///     W przypadku mocno rozbudowanych dodatków można umieścić plik .XML, który będzie przekierowywał
///     do wtyczki. Struktura pliku XML:
///
///     <PluginEU>
///         <Path>X:\(...).dll</Path>
///     </PluginEU>
///
/// </summary>
public class PluginEU
{
    /// <summary>
    /// Proszę tutaj wpisać nr wersji EU, dla której został opracowany dodatek. Użytkownicy
    /// starszych wersji zobaczą komunikat o konieczności aktualizacji aplikacji.
    /// </summary>
    public static string WersjaEU
    { get { return "3.44.0"; } }

    #region Test połączenia

    /// <summary>
    /// Moduł Aukcje
    /// </summary>
    [DisplayName("Test połączenia")]
    public static void A_Test()
    {
        MessageBox.Show("Działa!", "Moduł Aukcje");
    }

    /// <summary>
    /// Moduł Transakcje
    /// </summary>
    [DisplayName("Test połączenia")]
    public static void T_Test()
    {
        MessageBox.Show("Działa!", "Moduł Transakcje");
    }

    #endregion Test połączenia

    #region Moduł Aukcje

    /// <summary>
    /// Moduł Aukcje
    /// </summary>
    /// <param name="zazn_id">Tablica identyfikatorów zaznaczonych aukcji dla dodatków zintegrowanych z bazą EU.</param>
    [DisplayName("Eksportuj numery ID")]
    public static void A_Action(int[] zazn_id)
    {
        try
        {
            MessageBox.Show(string.Join(", ", zazn_id), "Moduł Aukcje");
        }
        catch (Exception E)
        {
            MessageBox.Show(E.Message);
        }
    }

    /// <summary>
    /// Moduł Aukcje
    /// </summary>
    /// <param name="zazn_xml">Zaznaczone aukcje w formacie XML. Aby zapoznać się ze strukturą danych można wyeksportować
    ///                        przykładową aukcję z EU do formatu XML - opcja pod prawym przyciskiem myszki na głównej liście.</param>
    [DisplayName("Eksportuj jako XML")]
    public static void A_Action(string zazn_xml)
    {
        XmlDocument xml = new XmlDocument();
        try
        {
            xml.LoadXml(zazn_xml);
            XmlNodeList xnList = xml.SelectNodes("/ArrayOfDaneAukcjiStruct/DaneAukcjiStruct");

            MessageBox.Show(xnList[0]["Tytul"].InnerText, "Moduł Aukcje");

            //foreach (XmlNode xnItem in xnList)
            //{
            //    MessageBox.Show(xnItem["Tytul"].InnerText);
            //}
        }
        catch (Exception E)
        {
            MessageBox.Show(E.Message);
        }
    }

    #endregion Moduł Aukcje

    #region Moduł Transakcje

    /// <summary>
    /// Moduł Transakcje
    /// </summary>
    /// <param name="zazn_id">Tablica identyfikatorów zaznaczonych transakcji dla dodatków zintegrowanych z bazą EU.</param>
    [DisplayName("Eksportuj numery ID")]
    public static void T_Action(int[] zazn_id)
    {
        try
        {
            MessageBox.Show(string.Join(", ", zazn_id), "Moduł Transakcje");
        }
        catch (Exception E)
        {
            MessageBox.Show(E.Message);
        }
    }

    /// <summary>
    /// Moduł Transakcje
    /// </summary>
    /// <param name="zazn_xml">Zaznaczone transakcje w formacie XML. Aby zapoznać się ze strukturą danych można wyeksportować
    ///                        przykładową transakcję z EU do formatu XML - opcja w menu eksportu do pliku nad główną listą.</param>
    [DisplayName("Eksportuj jako XML")]
    public static void T_Action(string zazn_xml)
    {
        XmlDocument xml = new XmlDocument();
        try
        {
            xml.LoadXml(zazn_xml);
            XmlNodeList xnList = xml.SelectNodes("/ArrayOfDaneTransStruct/DaneTransStruct");

            MessageBox.Show(xnList[0]["TytulAukcji"].InnerText, "Moduł Transakcje");

            //foreach (XmlNode xnItem in xnList)
            //{
            //    MessageBox.Show(xnItem["TytulAukcji"].InnerText);
            //}
        }
        catch (Exception E)
        {
            MessageBox.Show(E.Message);
        }
    }

    /// <summary>
    /// Moduł Transakcje - funkcja Pakuj
    ///
    /// Opis działania funkcji:
    /// https://www.easyuploader.pl/forum/viewtopic.php?t=3020
    ///
    /// Aby EU prawidłowo wykrył funkcje nazwa metody musi zaczynać się od "T_Pakuj_". Tak nazwane metody nie będą widoczne
    /// na liście oraz karcie transakcji. W oknie konfiguracji modułu Pakuj nazwa będzie widoczna w formacie:
    ///                     DisplayName (Nazwa pliku .DLL)
    /// </summary>
    /// <param name="zazn_xml">Zaznaczone transakcje w formacie XML. Aby zapoznać się ze strukturą danych można wyeksportować
    ///                        przykładową transakcję z EU do formatu XML - opcja w menu eksportu do pliku nad główną listą.</param>
    [DisplayName("Pakuj plugin")]
    public static void T_Pakuj_Action(string zazn_xml)
    {
        XmlDocument xml = new XmlDocument();
        try
        {
            // tutaj zawsze będzie tylko jedna transakcja
            xml.LoadXml(zazn_xml);
            XmlNodeList xnList = xml.SelectNodes("/ArrayOfDaneTransStruct/DaneTransStruct");

            MessageBox.Show(xnList[0]["TytulAukcji"].InnerText, "Moduł Transakcje - funkcja Pakuj");
        }
        catch (Exception E)
        {
            MessageBox.Show(E.Message);
        }
    }

    #endregion Moduł Transakcje

    #region Modyfikacja danych w bazie

    /// <summary>
    /// Istnieje możliwość modyfikacji danych bezpośrednio w bazie poprzez zwrócenie przez daną metodę
    /// zapytań SQL w formie tablicy string. Pierwsze z zapytań musi to być UPDATE lub INSERT, aby
    /// zostały wykonane wszystkie.
    ///
    /// Poniższy przykład przedstawia eksport transakcji do kuriera i zapisanie w bazie nr nadania
    /// przesyłki. Analogicznie można modyfikować dane aukcji. Lista aukcji/transakcji w EU
    /// odświeży się automatycznie.
    ///
    /// Do podglądu struktury bazy polecam aplikację FlameRobin (user SYSDBA, hasło masterkey, charset WIN1250).
    /// </summary>
    /// <param name="zazn_xml">Zaznaczone transakcje w formacie XML. Aby zapoznać się ze strukturą danych można wyeksportować
    ///                        przykładową transakcję z EU do formatu XML - opcja w menu eksportu do pliku nad główną listą.</param>
    [DisplayName("Eksportuj do kuriera")]
    public static string[] T_EksportKurier(string zazn_xml)
    {
        var sql = new List<string>();

        XmlDocument xml = new XmlDocument();
        try
        {
            xml.LoadXml(zazn_xml);
            XmlNodeList xnList = xml.SelectNodes("/ArrayOfDaneTransStruct/DaneTransStruct");

            foreach (XmlNode xnItem in xnList)
            {
                // tutaj nadajemy przesyłkę do systemu kuriera

                // zwrócony nr nadania zapisujemy w EU przy danej transakcji
                sql.Add($"UPDATE trans_wysylka SET nr_nadania='11111111111111' WHERE id_trans={xnItem["ID"].InnerText}");
            }
        }
        catch (Exception E)
        {
            MessageBox.Show(E.Message);
        }

        return sql.ToArray();
    }

    #endregion Modyfikacja danych w bazie
}